This dataset contains the processed reference dataset from the HeOrganAtlas dataset for Marrow tissue. It has been preprocessed to include log-normalized counts, specific metadata columns, and PCA, t-SNE, and UMAP results.
Details
This dataset underwent the following steps:
Loads the HeOrganAtlas dataset specifically for Marrow tissue from the
scRNAseqpackage.Divides the loaded dataset into a reference dataset used for downstream analysis.
Performs log normalization on the reference dataset using the function
logNormCountsfrom thescuttlepackage.Selects the column
expert_annotation) from the cell metadata for downstream analysis.Selects highly variable genes (HVGs) using the function
getTopHVGsfrom thescranpackage on the reference dataset.Performs Principal Component Analysis (PCA) on the reference dataset using the function
runPCAfrom thescaterpackage.Performs t-Distributed Stochastic Neighbor Embedding (t-SNE) on the reference dataset using the function
runTSNEfrom thescaterpackage.Performs Uniform Manifold Approximation and Projection (UMAP) on the reference dataset using the function
runUMAPfrom thescaterpackage.
References
He, et al. (2020). HeOrganAtlas: a comprehensive human organ atlas based on single-cell RNA sequencing.
Examples
# Load and explore the reference dataset
data("reference_data")